
# Slot: inverse


indicates that any instance of d s r implies that there is also an instance of r s' d

URI: [linkml:inverse](https://w3id.org/linkml/inverse)


## Domain and Range

[SlotDefinition](SlotDefinition.md) &#8594;  <sub>0..1</sub> [SlotDefinition](SlotDefinition.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | owl:inverseOf |

